summaryrefslogtreecommitdiffstats
path: root/korganizer/koeventview.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koeventview.h')
-rw-r--r--korganizer/koeventview.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/korganizer/koeventview.h b/korganizer/koeventview.h
index d2073d53..23d1bc44 100644
--- a/korganizer/koeventview.h
+++ b/korganizer/koeventview.h
@@ -61,10 +61,10 @@ class KOEventView : public KOrg::BaseView
* Constructs a view.
* @param cal is a pointer to the calendar object from which events
* will be retrieved for display.
* @param parent is the parent QWidget.
* @param name is the view name.
*/
- KOEventView(Calendar *cal,QWidget *parent=0,const char *name=0);
+ KOEventView(Calendar *cal,TQWidget *parent=0,const char *name=0);
/**
* Destructor. Views will do view-specific cleanups here.
@@ -85,7 +85,7 @@ class KOEventView : public KOrg::BaseView
/**
* Construct a standard context that allows to create a new event.
*/
- QPopupMenu *newEventPopup();
+ TQPopupMenu *newEventPopup();
/** This view is an view for displaying events. */
bool isEventView() { return true; }
@@ -113,7 +113,7 @@ class KOEventView : public KOrg::BaseView
* Emitted when an event is moved using the mouse in an agenda
* view (week / month).
*/
- void shiftedEvent(const QDate& olddate, const QDate& newdate);
+ void shiftedEvent(const TQDate& olddate, const TQDate& newdate);
protected slots:
@@ -61,10 +61,10 @@ class KOEventView : public KOrg::BaseView
* @param cal is a pointer to the calendar object from which events
* will be retrieved for display.
- * @param parent is the parent QWidget.
+ * @param parent is the parent TQWidget.
* @param name is the view name.
*/